@@ -24,12 +24,14 @@ class DataFrameSummary(object):
 
 
 
-    def __init__(self, df, plot=False):
+    def __init__(self, df, plot=False,continuous=[],categorical=[]):
         self.df = df
         self.length = len(df)
         self.columns_stats = self._get_stats()
         self.corr = df.corr()
         self.plot = plot
+        self.continuous=continuous
+        self.categorical=categorical
 
     def __getitem__(self, column):
         if isinstance(column, str) and self._clean_column(column):
@@ -60,16 +62,16 @@ class DataFrameSummary(object):
         raise KeyError(column)
 
     def _get_pairplot(self,data):
-        continuous=[]
-        categorical=[]
-        for i in data.columns:
-             if (data[i].nunique()/data.shape[0])*100 > 20 : ##unique nos in a column are more than 20% then it is a continuous variable
-                continuous.append(i)
-             else:
-                categorical.append(i)
-        cn=data.drop(columns=categorical,axis=1)
+        self.data=data
+        for i in self.data.columns:
+            if(self.data[i].nunique/self.data.shape[0])*100>20:
+                self.continuous.append(i)
+            else:
+                self.categorical.append(i)
+        cn=self.data.drop(columns=self.categorical,axis=1)
         return sn.pairplot(cn,corner=True,kind="scatter")
         
+        
     def _get_scatterplot(self,x,y,hue=None,style=None):
         return sn.scatterplot(x=x,y=y,hue=hue)
 
